SVG graphics — Python documentation

Note

Click here to download the full example code

# SVG graphics

Make sure we can embed SVG graphics.

Out:

    Text(0, 1, 'svg')

    import numpy as np
    import matplotlib.pyplot as plt

    from local_module import N  # N = 1000

    t = np.arange(N) / float(N)
    win = np.hanning(N)
    plt.figure()
    plt.plot(t, win, color='r')
    plt.text(0, 1, 'svg', size=40, va='top')

Total running time of the script: ( 0 minutes 0.067 seconds)

Gallery generated by Sphinx-Gallery